==> nextcloud-25.0.6.tgz: nextcloud/apps/twofactor_totp/l10n/fi.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Otit TOTP-tunnistautumisen käyttöön tililläsi",
    "You disabled TOTP two-factor authentication for your account" : "Poistit TOTP-tunnistautumisen käytöstä tililläsi",
    "TOTP two-factor authentication disabled by an admin" : "TOTP-kaksivaiheinen tunnistautuminen on poistettu käytöstä ylläpidon toimesta",
    "TOTP (Authenticator app)" : "TOTP (Authenticator-sovellus)",
    "Authenticate with a TOTP app" : "Tunnistaudu TOTP-sovelluksella",
    "Two-Factor TOTP Provider" : "Kaksivaiheinen TOTP-tarjoaja",
    "TOTP two-factor provider" : "TOTP-kaksivaiheisuuden tarjoaja",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Kaksivaiheisen tunnistautumisen tarjoaja TOTP:ille (RFC 6238)",
    "Enable TOTP" : "Käytä TOTP:tä",
    "Could not enable TOTP" : "TOTP:ia ei voitu ottaa käyttöön",
    "Could not verify your key. Please try again" : "Koodin tarkastus epäonnistui. Yritä uudelleen.",
    "Your new TOTP secret is:" : "Uusi TOTP-salaisuutesi on:",
    "For quick setup, scan this QR code with your TOTP app:" : "Skannaa tämä QR-koodi TOTP-sovelluksellasi asetusten nopeaa määritystä varten:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Kun olet määrittänyt sovelluksen, kirjoita testikoodi alle varmistaaksesi että kaikki toimii kunnolla:",
    "Authentication code" : "Tunnistautumiskoodi",
    "Verify" : "Vahvista",
    "Get the authentication code from the two-factor authentication app on your device." : "Hanki tunnistautumiskoodi laitteesi 2-vaiheisen tunnistautumisen sovelluksesta.",
    "Submit" : "Lähetä"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_totp/l10n/fi.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Otit TOTP-tunnistautumisen käyttöön tililläsi",
    "You disabled TOTP two-factor authentication for your account" : "Poistit TOTP-tunnistautumisen käytöstä tililläsi",
    "TOTP (Authenticator app)" : "TOTP (Authenticator-sovellus)",
    "Authenticate with a TOTP app" : "Tunnistaudu TOTP-sovelluksella",
    "Two-Factor TOTP Provider" : "Kaksivaiheinen TOTP-tarjoaja",
    "Enable TOTP" : "Käytä TOTP:tä",
    "Could not enable TOTP" : "TOTP:ia ei voitu ottaa käyttöön",
    "Could not verify your key. Please try again" : "Koodin tarkastus epäonnistui. Yritä uudelleen.",
    "Your new TOTP secret is:" : "Uusi TOTP-salaisuutesi on:",
    "For quick setup, scan this QR code with your TOTP app:" : "Skannaa tämä QR-koodi TOTP-sovelluksellasi asetusten nopeaa määritystä varten:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Kun olet määrittänyt sovelluksen, kirjoita testikoodi alle varmistaaksesi että kaikki toimii kunnolla:",
    "Authentication code" : "Tunnistautumiskoodi",
    "Verify" : "Vahvista",
    "Get the authentication code from the two-factor authentication app on your device." : "Hanki tunnistautumiskoodi laitteesi 2-vaiheisen tunnistautumisen sovelluksesta.",
    "Submit" : "Lähetä",
    "TOTP two-factor authentication disabled by an admin" : "TOTP-kaksivaiheinen tunnistautuminen on poistettu käytöstä ylläpidon toimesta",
    "TOTP two-factor provider" : "TOTP-kaksivaiheisuuden tarjoaja",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Kaksivaiheisen tunnistautumisen tarjoaja TOTP:ille (RFC 6238)"
},
"nplurals=2; plural=(n != 1);");
